// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<com.ibm.etools.cobol.preference.ui>>
//   (C) Copyright IBM Corp. 2001 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************

package com.ibm.etools.cobol.preference.ui.common;

import java.util.Vector;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Shell;

import com.ibm.etools.cobol.preference.ui.plugin.CobolPreferenceUIPlugin;



/**
 * A standard selection dialog.
 *
 * When the user selects a WSDL resource, a combo box is populated
 * with objects.  The dialog returns the selected object.
 *
 * The <code>getModelObject</code> method returns the selected object.
 */
public class CobolCodePageSelectionDialog extends org.eclipse.ui.dialogs.SelectionDialog
           implements org.eclipse.swt.events.SelectionListener {
	private static final String copyright = "(c) Copyright IBM Corporation 2001,2004.";

	private Object selectedObject;
	
	// the validation message
	private Label statusMessage;

	// widgets
	private Button okButton;
	private Button cancelButton;
	
	private Combo objectSelector;
	
	private Vector modelObjects = new Vector();
	
	private String filterPatterns;

	protected String _work;
	
	public CobolCodePageSelectionDialog(Shell parentShell, String work) {
		super(parentShell);

		_work = work;
		StringBuffer buffer = new StringBuffer();
		setShellStyle(getShellStyle() | SWT.RESIZE);
	}
	/* (non-Javadoc)
	 * Method declared in Window.
	 */
	protected void configureShell(Shell shell) {
		super.configureShell(shell);
		shell.setText(CobolPreferenceUIPlugin.getResource("%CODE_PAGE_SELECT_HEADER"));
	}
	/* (non-Javadoc)
	 * Method declared on Dialog.
	 */
	protected void createButtonsForButtonBar(Composite parent) {
		okButton = createButton(parent, IDialogConstants.OK_ID, IDialogConstants.OK_LABEL, true);
		cancelButton = createButton(parent, IDialogConstants.CANCEL_ID, IDialogConstants.CANCEL_LABEL, false);
	}
	/* (non-Javadoc)
	 * Method declared on Dialog.
	 */
	protected Control createDialogArea(Composite parent) {
	
		// create composite
		Composite dialogArea = (Composite)super.createDialogArea(parent);
		
		((GridData)dialogArea.getLayoutData()).widthHint = 200;
		((GridData)dialogArea.getLayoutData()).heightHint = 250;
	
		Listener listener = new Listener() {
			public void handleEvent (Event event) {
									
/****************
					if (modelObjects.size() > 0) {
						objectSelector.removeAll();
						objectSelector.setFocus();
						
						selectedObject = modelObjects.get(0);
						
						// enable the ok button
						if (getButton(IDialogConstants.OK_ID) != null) {
							getButton(IDialogConstants.OK_ID).setEnabled(true);
						}
					} else {	
						objectSelector.removeAll();
						statusMessage.setForeground(statusMessage.getDisplay().getSystemColor(SWT.COLOR_RED));
						statusMessage.setText(" ");
						
						// disable the ok button
						if (getButton(IDialogConstants.OK_ID) != null) {
							getButton(IDialogConstants.OK_ID).setEnabled(false);
						}	
					}
*************************/		
				}		
			};
		
	
		Label label = new Label(dialogArea,SWT.NONE);
		objectSelector = new Combo(dialogArea,SWT.SIMPLE);
	    objectSelector.setLayoutData(new GridData(GridData.FILL_BOTH));
		objectSelector.addSelectionListener(this);
		initialize();	
		
		GridData gridData = new GridData(GridData.FILL_BOTH);
		gridData.widthHint = 275;
		statusMessage = new Label(parent, SWT.NONE);
		statusMessage.setLayoutData(gridData);
	
		return dialogArea;
	}
	/**
	 * Closes this dialog.
	 */
	protected void okPressed() {
		super.okPressed();
	}

	/**
	 * Cancels this dialog.
	 */
	protected void cancelPressed() {
		selectedObject=null;
		super.cancelPressed();
	}

	public void widgetDefaultSelected(SelectionEvent event) {
	}
	
	public void widgetSelected(SelectionEvent event) {
		selectedObject = modelObjects.get(objectSelector.getSelectionIndex());
	}
	
	public Object getSelectedObject() {
		return selectedObject;
	}
	
	public void initialize()	{
		CobolCodePageFinder ccpf = new CobolCodePageFinder();
		Object [] sa = ccpf.findCCodePages();
		int match = -1;
		for(int i = 0; i < sa.length; i++)	{
			objectSelector.add((String) sa[i]);
			modelObjects.add(sa[i]);
			if(_work != null)
				if(sa[i].equals(_work))	match = i;
		}
		if(match >= 0)	{
			objectSelector.select(match);
		}
	}
}
